# ServiceFoundry

ServiceFoundry is a client library that allows you to containerize and deploy your Machine Learning model (or other
services) to a managed Kubernetes Cluster. This also generates a Grafana cluster with complete visibility of your
Service Health, System Logs, and Kubernetes Workspace.

It is available both as a command-line-interface and via APIs that allow you to deploy directly from your Jupyter
Notebook.

You can access the health of your service, monitoring links and deployed endpoints by logging on to TrueFoundry's
dashboard.

# Installation

```
pip install -U servicefoundry
```

# Documentation

https://docs.truefoundry.com/servicefoundry/
